@@ -172,6 +172,37 @@ setMethod("as.vector", "AtomicList",
     }
 )
 
+as.matrix.AtomicList <- function(x, col.names=NULL, ...) {
+    p <- PartitioningByEnd(x)
+    vx <- decode(unlist(x, use.names=FALSE))
+    if (is.null(col.names)) {
+        col.names <- names(vx)
+    }
+    if (is.null(col.names) || is.character(col.names)) {
+        col.ind <- as.integer(IRanges(1, width(p)))
+    } else if (is.list(col.names) || is(col.names, "List")) {
+        col.names <- unlist(col.names, use.names=FALSE)
+        if (is.factor(col.names)) {
+            col.ind <- as.integer(col.names)
+            col.names <- levels(col.names)
+        } else {
+            col.ind <- selfmatch(col.names)
+            col.names <- col.names[col.ind == seq_along(col.ind)]
+        }
+    } else {
+        stop("'col.names' should be NULL, a character vector or list")
+    }
+    row.ind <- togroup(p)
+    nc <- if (!is.null(col.names)) length(col.names) else max(width(p))
+    m <- matrix(nrow=length(x), ncol=nc)
+    m[cbind(row.ind, col.ind)] <- vx
+    if (!is.null(col.names))
+        colnames(m) <- col.names
+    m
+}
+setMethod("as.matrix", "AtomicList", function(x, col.names=NULL)
+    as.matrix.AtomicList(x, col.names))
+
 setMethod("drop", "AtomicList", function(x) {
   x_eltNROWS <- elementNROWS(x)
   if (any(x_eltNROWS > 1))
@@ -220,28 +251,6 @@ setListCoercions("factor")
 ### General methods
 ###
 
-.unique.RleList <- function(x, incomparables=FALSE, ...)
-    unique(runValue(x), incomparables=incomparables, ...)
-setMethod("unique", "RleList", .unique.RleList)
-
-.duplicated.CompressedIntegerList <- function(x, incomparables=FALSE,
-                                              fromLast=FALSE, ...)
-{
-  if (!identical(incomparables, FALSE))
-    stop("\"duplicated\" method for CompressedList objects ",
-         "does not support the 'incomparables' argument")
-  if (length(list(...)) > 0L) {
-    stop("arguments in '...' are not supported")
-  }
-  x_unlistData <- x@unlistData
-  x_group <- rep.int(seq_along(x), elementNROWS(x))
-  ans_unlistData <- duplicatedIntegerPairs(x_group, x_unlistData,
-                                           fromLast=fromLast)
-  relist(ans_unlistData, x)
-}
-setMethod("duplicated", "CompressedIntegerList",
-          .duplicated.CompressedIntegerList)
-
 ### Could actually be made the "table" method for List objects. Will work on
 ### any List object 'x' for which 'as.factor(unlist(x))' works.
 setMethod("table", "AtomicList",
@@ -471,16 +480,3 @@ setMethod("show", "RleList",
                              " more element>\n", " more elements>\n"),
                       sep="")
           })
-
-setMethod("showAsCell", "AtomicList",
-          function(object) {
-              if (length(object) == 0L)
-                return(character(0))
-              unlist(lapply(object, function(x) {
-                str <- paste(as.vector(head(x, 3)), collapse = ",") 
-                if (length(x) > 3)
-                  str <- paste(str, "...", sep = ",")
-                str
-              }), use.names = FALSE)
-          })
-
