@@ -265,6 +265,10 @@ setMethod("all", "CompressedAtomicList", function(x, na.rm = FALSE) {
               ans
           })
 
+setMethod("anyNA", "CompressedAtomicList", function(x, recursive=FALSE) {
+    callNextMethod(x, recursive=FALSE) ## recursion will just slow us down
+})
+
 rowsumCompressedList <- function(x, ..., na.rm = FALSE) {
   x_flat <- unlist(x, use.names = FALSE)
   ans <- vector(class(x_flat), length(x))
@@ -522,10 +526,21 @@ setMethods("which.max", list("IntegerList", "NumericList", "RleList"),
     function(x) setNames(as.integer(lapply(x, which.max)), names(x))
 )
 
+toglobal <- function(i, x) {
+    start(PartitioningByEnd(x)) + i - 1L
+}
+
 setCompressedListWhichSummaryMethod <-
     function(fun, where=topenv(parent.frame()))
     {
-        def <- function(x) .Call(C_fun, x)
+        def <- function(x, global = FALSE) {
+            stopifnot(isTRUEorFALSE(global))
+            ans <- .Call(C_fun, x)
+            if (global) {
+                ans <- toglobal(ans, x)
+            }
+            ans
+        }
         setCompressedNumericalListMethod(fun, def, where)
     }
 setCompressedListWhichSummaryMethod("which.min")
@@ -561,7 +576,8 @@ setMethod("mean", "AtomicList",
 setMethods("mean",
            list("CompressedLogicalList",
                 "CompressedIntegerList",
-                "CompressedNumericList"),
+                "CompressedNumericList",
+                "CompressedRleList"),
            function(x, trim = 0, na.rm = FALSE) {
                stopifnot(isTRUEorFALSE(na.rm))
                stopifnot(isSingleNumber(trim))
@@ -609,6 +625,27 @@ setMethod("median", "AtomicList",
     function(x, na.rm=FALSE) sapply(x, median, na.rm=na.rm)
 )
 
+setMethod("median", "CompressedAtomicList", function(x, na.rm=FALSE) {
+    stopifnot(isTRUEorFALSE(na.rm))
+    sx <- sort(x)
+    n <- lengths(sx)
+    half <- (n + 1L)%/%2L
+    even <- n%%2L != 1L
+    ind <- IRanges(half, width=1L+even)
+    NAs <- half == 0L
+    ind <- relist(ind[!NAs], PartitioningByWidth(as.integer(!NAs)))
+    ## ind <- as(half, "IntegerList")
+    ## ind[even] <- ind[even] + as(0:1, "IntegerList")
+    ans <- mean(sx[ind])
+    if (!na.rm) {
+        NAs <- NAs | anyNA(x)
+    }
+    if (any(NAs)) {
+        ans[NAs] <- as(NA, elementType(x))
+    }
+    ans
+})
+
 setMethod("quantile", "AtomicList",
     function(x, ...) sapply(x, quantile, ...)
 )
@@ -732,6 +769,11 @@ setMethod("unstrsplit", "CharacterList",
     function(x, sep="") unstrsplit(as.list(x), sep=sep)
 )
 
+setMethod("unstrsplit", "RleList",
+          function(x, sep="") unstrsplit(CharacterList(x, compress=FALSE),
+                                         sep=sep)
+          )
+
 setMethod("paste", "CompressedAtomicList",
           function(..., sep=" ", collapse=NULL) {
               args <- lapply(list(...), as, "CharacterList")
@@ -746,3 +788,97 @@ setMethod("paste", "CompressedAtomicList",
               ans
           })
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Sorting
+###
+
+setMethod("rank", "CompressedAtomicList",
+          function (x, na.last = TRUE,
+                    ties.method = c("average", "first",
+                                    "last", "random", "max", "min"))
+          {
+              stopifnot(isTRUE(na.last))
+              ties.method <- match.arg(ties.method)
+              if (ties.method == "last" || ties.method == "random")
+                  stop("'ties.method' last/random not yet supported")
+              p <- PartitioningByEnd(x)
+              o <- order(togroup(p), unlist(x, use.names=FALSE))
+              r <- as.integer(IRanges(1L, width=width(p)))
+              gp <- PartitioningByEnd(end(Rle(unlist(x, use.names=FALSE)[o])))
+              v <- switch(ties.method,
+                          average=(r[start(gp)] + r[end(gp)])/2,
+                          first=r,
+                          ## last=,
+                          ## random=,
+                          max=r[end(gp)],
+                          min=r[start(gp)])
+              if (ties.method != "first")
+                  v <- rep(v, width(gp))
+              r[o] <- v
+              relist(r, x)
+          })
+
+setMethod("order", "CompressedAtomicList",
+          function (..., na.last = TRUE, decreasing = FALSE,
+                    method = c("shell", "radix"))
+{
+    args <- list(...)
+    if (length(args) != 1L) 
+        stop("\"order\" method for CompressedAtomicList objects ",
+             "can only take one input object")
+    x <- args[[1L]]
+    p <- PartitioningByEnd(x)
+    ux <- unlist(x, use.names=FALSE)
+    o <- order(togroup(p), ux, na.last=na.last,
+               decreasing=decreasing, method=method)
+    skeleton <- if (is.na(na.last) && anyNA(ux)) {
+        skeleton <- PartitioningByWidth(width(p) - sum(is.na(x)))
+    } else p
+    relist(o, skeleton) - start(p) + 1L
+})
+    
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Set/comparison methods
+###
+
+subgrouping <- function(x) {
+    g <- grouping(togroup(PartitioningByEnd(x)), unlist(x, use.names=FALSE))
+    as(g, "ManyToOneGrouping")
+}
+
+.unique.RleList <- function(x, incomparables=FALSE, ...)
+    unique(runValue(x), incomparables=incomparables, ...)
+setMethod("unique", "RleList", .unique.RleList)
+
+.duplicated.CompressedAtomicList <- function(x, incomparables=FALSE,
+                                             fromLast=FALSE, nmax=NA, ...)
+{
+    if (!identical(incomparables, FALSE))
+        stop("\"duplicated\" method for CompressedList objects ",
+             "does not support the 'incomparables' argument")
+    if (length(list(...)) > 0L) {
+        stop("arguments in '...' are not supported")
+    }
+    stopifnot(isTRUEorFALSE(fromLast))
+    g <- subgrouping(x)
+    p <- PartitioningByEnd(g)
+    first <- unlist(g)[if (fromLast) end(p) else start(p)]
+    v <- rep(TRUE, length(unlist(g)))
+    v[first] <- FALSE
+    relist(v, x)
+}
+setMethod("duplicated", "CompressedAtomicList",
+          .duplicated.CompressedAtomicList)
+
+setMethod("selfmatch", "CompressedAtomicList", function(x, global=FALSE) {
+    g <- subgrouping(x)
+    first <- unlist(g)[start(PartitioningByEnd(g))]
+    ux <- unlist(x, use.names=FALSE)
+    ux[unlist(g)] <- rep(first, lengths(g))
+    ans <- relist(ux, x)
+    if (!global) {
+        ans <- ans - start(ans) + 1L
+    }
+    ans
+})
+
