@@ -39,10 +39,9 @@ setMethod("stack", "List",
           {
             value <- unlist(x, use.names=FALSE)
             index <- .stack.ind(x, index.var)
-            unlistsToList <- extends(x@elementType, "List") &&
-                !extends(x@elementType, "Ranges")
-            if (unlistsToList) {
-              df <- cbind(S4Vectors:::ensureMcols(value), index)
+            unlistsToVector <- is(value, "Vector")
+            if (unlistsToVector) {
+              df <- cbind(S4Vectors:::ensureMcols(unname(value)), index)
             } else {
               df <- DataFrame(index, as(value, "DataFrame"))
               colnames(df)[2] <- value.var
@@ -51,14 +50,18 @@ setMethod("stack", "List",
               nms <- as.character(unlist(lapply(x, names)))
               if (length(nms) == 0L) {
                 rngs <- IRanges(1L, width=elementNROWS(x))
-                nms <- as.character(as.integer(rngs))
+                nms <- as.integer(rngs)
+              } else {
+                nms <- factor(nms, unique(nms))
               }
-              df[[name.var]] <- factor(nms, unique(nms))
+              df[[name.var]] <- nms
+              df <- df[c(index.var, name.var, value.var)]
             }
             if (!is.null(mcols(x))) {
-              df <- cbind(df, mcols(x))
+                df <- cbind(df,
+                            mcols(x)[togroup(PartitioningByEnd(x)),,drop=FALSE])
             }
-            if (unlistsToList) {
+            if (unlistsToVector) {
               mcols(value) <- df
               value
             } else {
@@ -66,3 +69,24 @@ setMethod("stack", "List",
             }
           })
 
+setMethod("stack", "matrix",
+          function(x, row.var = names(dimnames(x))[1L],
+                   col.var = names(dimnames(x))[2L])
+          {
+              l <- x
+              attributes(l) <- NULL
+              lens <- elementNROWS(l)
+              rn <- rownames(x)
+              if (is.null(rn))
+                  rn <- seq_along(nrow(x))
+              cn <- colnames(x)
+              if (is.null(cn))
+                  cn <- seq_along(ncol(x))
+              ans <- DataFrame(row=rep(rn[row(x)], lens),
+                               col=rep(Rle(cn, rep(nrow(x), ncol(x))), lens),
+                               stack(List(l)))
+              if (is.null(row.var)) row.var <- "row"
+              if (is.null(col.var)) col.var <- "col"
+              colnames(ans) <- c(row.var, col.var)
+              ans
+          })
