@@ -18,10 +18,9 @@ setClass("RDApplyParams",
 ###
 
 setGeneric("rangedData", function(x, ...) standardGeneric("rangedData"))
-setMethod("rangedData", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@rangedData
-})
+setMethod("rangedData", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("rangedData<-",
            function(x, ..., value) standardGeneric("rangedData<-"))
@@ -32,10 +31,9 @@ setReplaceMethod("rangedData", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("applyFun", function(x, ...) standardGeneric("applyFun"))
-setMethod("applyFun", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@applyFun
-})
+setMethod("applyFun", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("applyFun<-", function(x, ..., value) standardGeneric("applyFun<-"))
 setReplaceMethod("applyFun", "RDApplyParams", function(x, value) {
@@ -45,10 +43,9 @@ setReplaceMethod("applyFun", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("applyParams", function(x, ...) standardGeneric("applyParams"))
-setMethod("applyParams", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@applyParams
-})
+setMethod("applyParams", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("applyParams<-",
            function(x, ..., value) standardGeneric("applyParams<-"))
@@ -70,10 +67,9 @@ setReplaceMethod("applyParams", "RDApplyParams", function(x, value) {
 ##   x
 ## })
 
-setMethod("filterRules", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@filterRules
-})
+setMethod("filterRules", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("filterRules<-",
            function(x, ..., value) standardGeneric("filterRules<-"))
@@ -84,10 +80,9 @@ setReplaceMethod("filterRules", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("simplify", function(x, ...) standardGeneric("simplify"))
-setMethod("simplify", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@simplify
-})
+setMethod("simplify", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("simplify<-", function(x, ..., value) standardGeneric("simplify<-"))
 setReplaceMethod("simplify", "RDApplyParams", function(x, value) {
@@ -97,10 +92,9 @@ setReplaceMethod("simplify", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("reducerFun", function(x, ...) standardGeneric("reducerFun"))
-setMethod("reducerFun", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@reducerFun
-})
+setMethod("reducerFun", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("reducerFun<-",
            function(x, ..., value) standardGeneric("reducerFun<-"))
@@ -111,10 +105,9 @@ setReplaceMethod("reducerFun", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("reducerParams", function(x, ...) standardGeneric("reducerParams"))
-setMethod("reducerParams", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@reducerParams
-})
+setMethod("reducerParams", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("reducerParams<-", function(x, ..., value)
            standardGeneric("reducerParams<-"))
@@ -125,10 +118,9 @@ setReplaceMethod("reducerParams", "RDApplyParams", function(x, value) {
 })
 
 setGeneric("iteratorFun", function(x, ...) standardGeneric("iteratorFun"))
-setMethod("iteratorFun", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  x@iteratorFun
-})
+setMethod("iteratorFun", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 setGeneric("iteratorFun<-", function(x, ..., value)
            standardGeneric("iteratorFun<-"))
@@ -146,15 +138,7 @@ setReplaceMethod("iteratorFun", "RDApplyParams", function(x, value) {
 RDApplyParams <- function(rangedData, applyFun, applyParams, #excludePattern,
                           filterRules, simplify, reducerFun, reducerParams,
                           iteratorFun)
-{
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  params <- new("RDApplyParams", applyFun = applyFun,
-                applyParams = applyParams, filterRules = filterRules,
-                simplify = simplify, reducerFun = reducerFun,
-                reducerParams = reducerParams, iteratorFun = iteratorFun)
-  params@rangedData <- rangedData ## set rangedData last for efficiency
-  params
-}
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
 
 ## get the defaults from the class prototype
 formals(RDApplyParams) <- structure(lapply(slotNames("RDApplyParams"),
@@ -168,73 +152,7 @@ formals(RDApplyParams) <- structure(lapply(slotNames("RDApplyParams"),
 ### Validity.
 ###
 
-.valid.RDApplyParams.applyFun <- function(x) {
-  formals <- formals(applyFun(x))
-  if (anyDuplicated(names(applyParams(x))))
-    "apply parameters have duplicated names"
-  else if (!("..." %in% names(formals))) {
-    if (length(formals) < (length(applyParams(x)) + 1))
-      "'applyFun' does not take enough parameters"
-    else {
-      nms <- names(applyParams(x))
-      if (!is.null(nms) && !all(nms[nchar(nms) > 0] %in% names(formals)))
-        "mismatch between names of 'applyParams' and formals of 'applyFun'"
-      else NULL
-    }
-  } else NULL
-}
-
-## .valid.RDApplyParams.excludePattern <- function(x) {
-##   if (!isSingleString(excludePattern(x)))
-##     "'excludePattern' must be a single, non-missing string"
-##   else NULL
-## }
-
-.valid.RDApplyParams.simplify <- function(x) {
-  if (!isTRUEorFALSE(simplify(x)))
-    "'simplify' must be TRUE or FALSE"
-  else if (!is.null(reducerFun(x)) && simplify(x))
-    "'simplify' must be FALSE for there to be a 'reducerFun'"
-  else NULL
-}
-
-.valid.RDApplyParams.reducerParams <- function(x) {
-  if (length(reducerParams(x)) && is.null(reducerFun(x)))
-    return("there must be a 'reducerFun' for there to be 'reducerParams'")
-  else if (anyDuplicated(names(reducerParams(x))))
-    return("reducer parameters have duplicated names")
-  else if (!is.null(reducerFun(x))) {
-    formals <- formals(reducerFun(x))
-    if (!("..." %in% names(formals))) {
-      if (length(formals) < (length(reducerParams(x)) + 1))
-        return("'reducerFun' does not take enough parameters")
-      else {
-        nms <- names(reducerParams(x))
-        if (!is.null(nms) && !all(nms[nchar(nms) > 0] %in% names(formals)) &&
-            !("..." %in% names(formals)))
-          return("mismatch b/w 'reducerParams' names and 'reducerFun' formals")
-      }
-    }
-  }
-  NULL
-}
-
-.valid.RDApplyParams.iteratorFun <- function(x) {
-  formals <- formals(iteratorFun(x))
-  if (length(formals) < 2)
-    "'iteratorFun' must take at least two parameters"
-  else if ("simplify" %in% names(formals) && length(formals) < 3)
-    "'iteratorFun' must take at least three parameters if one is 'simplify'"
-  else NULL
-}
-
-.valid.RDApplyParams <- function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  c(##.valid.RDApplyParams.rangedData(x),
-    .valid.RDApplyParams.applyFun(x),
-    ##.valid.RDApplyParams.excludePattern(x),
-    .valid.RDApplyParams.simplify(x), .valid.RDApplyParams.reducerParams(x),
-    .valid.RDApplyParams.iteratorFun(x))
-}
+.valid.RDApplyParams <- function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
 
 setValidity2("RDApplyParams", .valid.RDApplyParams)
