@@ -25,39 +25,9 @@ setMethod("endoapply", "RangedData",
 
 setGeneric("rdapply", function(x, ...) standardGeneric("rdapply"))
 
-setMethod("rdapply", "RDApplyParams", function(x) {
-  .Deprecated(msg="RDApplyParams objects and rdapply() are deprecated")
-  rd <- rangedData(x)
-  applyFun <- applyFun(x)
-  applyParams <- applyParams(x)
-  rules <- filterRules(x)
-  simplify <- simplify(x)
-  reducerFun <- reducerFun(x)
-  reducerParams <- reducerParams(x)
-  enclos <- parent.frame(2) 
-  inds <- seq(length(rd))
-  names(inds) <- names(rd)
-  ##   if (length(excludePattern)) {
-  ##     excludePattern <- grep(excludePattern, names(rd))
-  ##     if (length(excludePattern))
-  ##       inds <- inds[-excludePattern]
-  ##   }
-  forEachSpace <- function(i) {
-    rdi <- rd[i]
-    if (length(rules)) {
-      filter <- eval(rules, rdi, enclos)
-      rdi <- rdi[filter,]
-    }
-    do.call(applyFun, c(list(rdi), applyParams))
-  }
-  iteratorFun <- iteratorFun(x)
-  if ("simplify" %in% names(formals(iteratorFun)))
-    ans <- iteratorFun(inds, forEachSpace, simplify = simplify)
-  else ans <- iteratorFun(inds, forEachSpace)
-  if (!is.null(reducerFun))
-    ans <- do.call(reducerFun, c(list(ans), reducerParams))
-  ans
-})
+setMethod("rdapply", "RDApplyParams", function(x)
+  .Defunct(msg="RDApplyParams objects and rdapply() are defunct")
+)
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### within()
