@@ -93,10 +93,10 @@ setMethod(".replaceSEW", "RangesList",
     {
         if (extends(class(value), "IntegerList")) {
             if (!identical(lapply(x, names), lapply(value, names)) &&
-                !all(elementLengths(x) == elementLengths(value)))
+                !all(elementNROWS(x) == elementNROWS(value)))
                 stop("'value' must have same length and names as current 'ranges'")
         } else if (is.numeric(value)) {
-            lelts <- sum(elementLengths(x))
+            lelts <- sum(elementNROWS(x))
             if (lelts != length(value))
                 value <- rep(value, length.out = lelts)
             if (!is.integer(value))
@@ -142,11 +142,11 @@ setMethod(".replaceSEW", "CompressedIRangesList",
     {
         if (extends(class(value), "IntegerList")) {
             if (!identical(lapply(x, names), lapply(value, names)) &&
-                !all(elementLengths(x) == elementLengths(value)))
+                !all(elementNROWS(x) == elementNROWS(value)))
                 stop("'value' must have same length and names as current 'ranges'")
             value <- unlist(value)
         } else if (is.numeric(value)) {
-            lelts <- sum(elementLengths(x))
+            lelts <- sum(elementNROWS(x))
             if (lelts != length(value))
                 value <- rep(value, length.out = lelts)
             if (!is.integer(value))
@@ -161,13 +161,12 @@ setMethod(".replaceSEW", "CompressedIRangesList",
     }
 )
 
-setGeneric("space", function(x, ...) standardGeneric("space"))
 setMethod("space", "RangesList",
           function(x)
           {
             space <- names(x)
             if (!is.null(space))
-              space <- factor(rep.int(space, elementLengths(x)), space)
+              space <- factor(rep.int(space, elementNROWS(x)), unique(space))
             space
           })
 
@@ -190,30 +189,33 @@ setReplaceMethod("universe", "RangesList",
                  })
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### isNormal(), isDisjoint()
+### isNormal()
 ###
 ### Test the list elements of a RangesList object 'x' individually and return
-### a vector of TRUE's or FALSE's parallel to 'x'. More precisely, they're
-### equivalent to 'sapply(x, FUN)', when FUN is 'isNormal' or 'isDisjoint'.
+### a vector of TRUE's or FALSE's parallel to 'x'. More precisely, is
+### equivalent to 'sapply(x, FUN)', when FUN is 'isNormal'.
 ###
 
 setMethod("isNormal", "RangesList",
-          function(x) unlist(lapply(x, isNormal)))
-
-setMethod("isNormal", "CompressedIRangesList",
-          function(x)
-          .Call2("CompressedIRangesList_isNormal", x, TRUE, PACKAGE = "IRanges"))
+    function(x, use.names=FALSE)
+        vapply(x, isNormal, logical(1), USE.NAMES=use.names)
+)
 
 setMethod("isNormal", "SimpleIRangesList",
-          function(x)
-          .Call2("SimpleIRangesList_isNormal", x, PACKAGE = "IRanges"))
+    function(x, use.names=FALSE)
+        .Call2("SimpleIRangesList_isNormal", x, use.names,
+               PACKAGE="IRanges")
+)
+
+setMethod("isNormal", "CompressedIRangesList",
+    function(x, use.names=FALSE)
+        .Call2("CompressedIRangesList_isNormal", x, use.names,
+               PACKAGE="IRanges")
+)
 
 setMethod("whichFirstNotNormal", "RangesList",
           function(x) unlist(lapply(x, whichFirstNotNormal)))
 
-setMethod("isDisjoint", "RangesList",
-          function(x) unlist(lapply(x, isDisjoint)))
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Constructor.
@@ -393,7 +395,6 @@ setMethod("showAsCell", "RangesList",
 ### Coercion.
 ###
 
-### S3/S4 combo for as.list.CompressedNormalIRangesList
 .as.list.CompressedNormalIRangesList <- function(x, use.names=TRUE)
 {
     if (!isTRUEorFALSE(use.names))
@@ -403,10 +404,8 @@ setMethod("showAsCell", "RangesList",
         names(ans) <- names(x)
     ans
 }
-as.list.CompressedNormalIRangesList <- function(x, ...)
-    .as.list.CompressedNormalIRangesList(x, ...)
 setMethod("as.list", "CompressedNormalIRangesList",
-    as.list.CompressedNormalIRangesList)
+    .as.list.CompressedNormalIRangesList)
 
 setMethod("unlist", "SimpleNormalIRangesList",
           function(x, recursive = TRUE, use.names = TRUE)
@@ -452,48 +451,62 @@ setAs("RangesList", "SimpleRangesList",
                                            metadata = metadata(from),
                                            mcols = mcols(from)))
 
-setAs("RangesList", "NormalIRangesList",
-      function(from)
-      {
-        if (is(from, "CompressedList"))
-          as(from, "CompressedNormalIRangesList")
-        else
-          as(from, "SimpleNormalIRangesList")
-      })
+### Coercion from RangesList to NormalIRangesList.
 
-setAs("RangesList", "CompressedNormalIRangesList",
-      function(from)
-      new_CompressedList_from_list("CompressedNormalIRangesList",
-                                   lapply(from, as, "NormalIRanges"),
-                                   metadata = metadata(from),
-                                   mcols = mcols(from)))
+.from_RangesList_to_SimpleNormalIRangesList <- function(from)
+{
+    S4Vectors:::new_SimpleList_from_list("SimpleNormalIRangesList",
+        lapply(from, as, "NormalIRanges"),
+        mcols=mcols(from),
+        metadata=metadata(from))
+}
 
 setAs("RangesList", "SimpleNormalIRangesList",
-      function(from)
-      S4Vectors:::new_SimpleList_from_list("SimpleNormalIRangesList",
-                                           lapply(from, as, "NormalIRanges"),
-                                           metadata = metadata(from),
-                                           mcols = mcols(from)))
-
-setAs("CompressedIRangesList", "CompressedNormalIRangesList",
-      function(from)
-      {
-        if (!all(isNormal(from)))
-          from <- reduce(from, drop.empty.ranges=TRUE)
-        new2("CompressedNormalIRangesList", from, check=FALSE)
-      })
+    .from_RangesList_to_SimpleNormalIRangesList
+)
 
 setAs("SimpleIRangesList", "SimpleNormalIRangesList",
-      function(from)
-      {
-        if (!all(isNormal(from))) 
-          from <- reduce(from, drop.empty.ranges=TRUE)
-        new2("SimpleNormalIRangesList",
-             listData = lapply(from@listData, newNormalIRangesFromIRanges,
-               check = FALSE),
-             metadata = from@metadata,
-             elementMetadata = from@elementMetadata, check=FALSE)
-      })
+    .from_RangesList_to_SimpleNormalIRangesList
+)
+
+setAs("NormalIRangesList", "CompressedNormalIRangesList",
+    function(from)
+    {
+        ans <- as(from, "CompressedIRangesList", strict=FALSE)
+        class(ans) <- "CompressedNormalIRangesList"
+        ans
+    }
+)
+
+setAs("CompressedIRangesList", "CompressedNormalIRangesList",
+    function(from)
+    {
+        if (!all(isNormal(from)))
+            from <- reduce(from, drop.empty.ranges=TRUE)
+        class(from) <- "CompressedNormalIRangesList"
+        from
+    }
+)
+
+setAs("RangesList", "CompressedNormalIRangesList",
+    function(from)
+    {
+        as(as(from, "CompressedIRangesList", strict=FALSE),
+           "CompressedNormalIRangesList")
+    }
+)
+
+setAs("RangesList", "NormalIRangesList",
+    function(from)
+    {
+        if (is(from, "SimpleRangesList"))
+            as(from, "SimpleNormalIRangesList")
+        else
+            as(from, "CompressedNormalIRangesList")
+    }
+)
+
+### Coercion from LogicalList to IRangesList.
 
 setAs("LogicalList", "IRangesList",
       function(from)
@@ -518,6 +531,8 @@ setAs("LogicalList", "SimpleIRangesList",
                                            metadata = metadata(from),
                                            mcols = mcols(from)))
 
+### Coercion from LogicalList to NormalIRangesList.
+
 setAs("LogicalList", "NormalIRangesList",
       function(from)
       {
@@ -541,6 +556,8 @@ setAs("LogicalList", "SimpleNormalIRangesList",
                                            metadata = metadata(from),
                                            mcols = mcols(from)))
 
+### Coercion from RleList to IRangesList.
+
 setAs("RleList", "IRangesList",
       function(from)
       {
@@ -595,6 +612,8 @@ setAs("RleList", "SimpleIRangesList",
       })
 
 
+### Coercion from RleList to NormalIRangesList.
+
 setAs("RleList", "NormalIRangesList",
         function(from)
         {
@@ -632,6 +651,8 @@ setAs("RleList", "SimpleNormalIRangesList",
                                              mcols = mcols(from))
       })
 
+### Other coercions.
+
 setAs("list", "RangesList", function(from) {
   S4Vectors:::coerceToSimpleList(from, "Ranges")
 })
@@ -640,6 +661,7 @@ setAs("Ranges", "RangesList", function(from) {
           relist(from, PartitioningByEnd(seq_along(from), names=names(from)))
       })
 
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### The "max" and "min" methods for NormalIRangesList objects.
 ###
