@@ -7,15 +7,6 @@
 ### or in IRanges).
 ###
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Internal utility
-###
-
-setMethod("showAsCell", "list", function(object)
-          rep.int("########", length(object)))
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Other subsetting-related operations
 ###
@@ -116,7 +107,7 @@ setMethod("mstack", "Vector", function(..., .index.var = "name") {
   combined <- compress_listData(args)
   df <- .stack.ind(args, .index.var)
   if (!is.null(mcols(combined)))
-    df <- cbind(mcols(combined), df)
+    df <- cbind(df, mcols(combined))
   mcols(combined) <- df
   combined
 })
