@@ -172,15 +172,20 @@ setMethod("relist", c("Vector", "list"),
         idx <- base::order(f_vals)
         xranges <- successiveIRanges(f_lens)[idx]
         x <- extractROWS(x, xranges)
+        f <- S4Vectors:::tabulate2(f_vals, nbins=length(f_levels),
+                                   weight=f_lens)
+        if (drop) {
+            f_levels <- f_levels[f != 0L]
+            f <- f[f != 0L]
+        }
+    } else if (length(f_vals) == length(f_levels) || drop) {
+        if (drop) f_levels <- as.character(runValue(f))
+        f <- f_lens
+    } else {
+        f <- integer(length(f_levels))
+        f[f_vals] <- f_lens
     }
-    ## Using S4Vectors:::tabulate2() is 5x faster than doing:
-    ##   f <- integer(length(f_levels))
-    ##   tmp <- Rle(f_vals[idx], f_lens[idx])
-    ##   f[runValue(tmp)] <- runLength(tmp)
-    f <- S4Vectors:::tabulate2(f_vals, nbins=length(f_levels), weight=f_lens)
     names(f) <- f_levels
-    if (drop)
-        f <- f[f != 0L]
     f <- cumsum(f)
     f <- PartitioningByEnd(f)
     relist(x, f)
@@ -190,10 +195,18 @@ setGeneric("splitAsList", signature=c("x", "f"),
     function(x, f, drop=FALSE, ...) standardGeneric("splitAsList")
 )
 
+toFactor <- function(x) {
+    if (is(x, "Rle")) {
+        runValue(x) <- as.factor(runValue(x))
+        x
+    } else as.factor(x)
+}
+
 ### Took this out of the still-in-incubation LazyList package
-factorsToTableIndices <- function(factors) {
+interaction2 <- function(factors) {
   nI <- length(factors)
   nx <- length(factors[[1L]])
+  factors <- lapply(factors, toFactor)
   useRle <- any(vapply(factors, is, logical(1), "Rle"))
   if (useRle) {
     group <- as(factors[[1L]], "Rle")
@@ -213,15 +226,28 @@ factorsToTableIndices <- function(factors) {
     group <- group + offset
     ngroup <- ngroup * nlevels(index)
   }
-  as.vector(group)
+  if (useRle) {
+      runValue(group) <- structure(runValue(group),
+                                   levels=as.character(seq_len(ngroup)),
+                                   class="factor")
+      group
+  } else {
+      structure(group, levels=as.character(seq_len(ngroup)), class="factor")
+  }
 }
 
 normSplitFactor <- function(f, x) {
   if (is(f, "formula")) {
+    if (length(f) == 3L)
+      stop("formula 'f' should not have a left hand side")
     f <- S4Vectors:::formulaValues(x, f)
   }
   if (is.list(f) || is(f, "List")) {
-    f <- factorsToTableIndices(f)
+      if (length(f) == 1L) {
+          f <- toFactor(f[[1L]])
+      } else {
+          f <- interaction2(f)
+      }
   }
   f_len <- length(f)
   if (f_len < NROW(x)) {
@@ -234,16 +260,33 @@ normSplitFactor <- function(f, x) {
   f
 }
 
+## about 3X faster than as.factor on a ~450k tx ids
+## caveats: no NAs, and radix sort of levels does not support all encodings
+## todo: Would be faster if sort() returned grouping info,
+##       but then we might coalesce this with the order/split.
+## todo: if we could pass na.rm=TRUE to grouping(), NAs would be handled
+as.factor2 <- function(x) {
+    if (is.factor(x))
+        return(x)
+    g <- grouping(x)
+    p <- PartitioningByEnd(relist(g))
+    levs <- as.character(x[g[end(p)]])
+    o <- order(levs, method="radix")
+    v <- integer(length(levs)) # or rep(NA_integer_, length(levs)) for NAs
+    v[o] <- seq_along(o)
+    f <- integer(length(x))
+    f[g] <- v[togroup(p)]
+    structure(f, levels=levs[o], class="factor")
+}
+
 splitAsList_default <- function(x, f, drop=FALSE)
 {
     if (!isTRUEorFALSE(drop))
         stop("'drop' must be TRUE or FALSE")
 
     f <- normSplitFactor(f, x)
-    is_na <- is.na(f)
-    na_idx <- which(is_na)
-    if (length(na_idx) != 0L) {
-        keep_idx <- seq_len(NROW(x))[-na_idx]
+    if (anyNA(f)) {
+        keep_idx <- which(!is.na(f))
         x <- extractROWS(x, keep_idx)
         f <- f[keep_idx]
     }
@@ -251,7 +294,7 @@ splitAsList_default <- function(x, f, drop=FALSE)
     if (is.integer(f))
         return(.splitAsList_by_integer(x, f, drop))
     if (!is(f, "Rle")) {
-        f <- as.factor(f)
+        f <- as.factor2(f)
         return(.splitAsList_by_factor(x, f, drop))
     }
     ## From now on, 'f' is guaranteed to be an Rle.
@@ -263,14 +306,9 @@ splitAsList_default <- function(x, f, drop=FALSE)
     return(.splitAsList_by_Rle(x, f, drop))
 }
 
-setMethod("splitAsList", c("ANY", "vectorORfactor"),
-          function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop))
-setMethod("splitAsList", c("ANY", "Rle"),
-          function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop))
-setMethod("splitAsList", c("ANY", "List"),
-          function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop))
-setMethod("splitAsList", c("ANY", "formula"),
-          function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop))
+setMethod("splitAsList", c("ANY", "ANY"),
+    function(x, f, drop=FALSE) splitAsList_default(x, f, drop=drop)
+)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -370,8 +408,9 @@ resplit <- function(x, f) {
 
 regroup <- function(x, g) {
     g <- as(g, "Grouping")
-    ends <- end(PartitioningByEnd(g))
-    ix <- unlist(g, use.names=FALSE)
-    p <- PartitioningByEnd(end(PartitioningByEnd(x))[ix][ends])
-    relist(unlist(x[ix], use.names=FALSE), p)
+    gends <- end(PartitioningByEnd(g))
+    xg <- x[unlist(g, use.names=FALSE)]
+    p <- PartitioningByEnd(end(PartitioningByEnd(xg))[gends])
+    names(p) <- names(g)
+    relist(unlist(xg, use.names=FALSE, recursive=FALSE), p)
 }
