@@ -89,7 +89,7 @@ setMethod("findOverlaps", c("Vector", "missing"),
     {
         if (!identical(ignoreSelf, FALSE) ||
             !identical(ignoreRedundant, FALSE)) {
-            .Deprecated(msg=wmsg(
+            .Defunct(msg=wmsg(
                 "Please use 'drop.self' and/or 'drop.redundant' instead ",
                 "of the 'ignoreSelf' and/or 'ignoreRedundant' arguments."
             ))
@@ -659,55 +659,62 @@ setMethod("poverlaps", c("Ranges", "integer"),
 setGeneric("subsetByOverlaps", signature=c("query", "subject"),
     function(query, subject, maxgap=0L, minoverlap=1L,
              type=c("any", "start", "end", "within", "equal"),
-             ...)
+             invert=FALSE, ...)
         standardGeneric("subsetByOverlaps")
 )
 
 setMethod("subsetByOverlaps", c("Vector", "Vector"),
     function(query, subject, maxgap=0L, minoverlap=1L,
-             type=c("any", "start", "end", "within", "equal"),
+             type=c("any", "start", "end", "within", "equal"), invert=FALSE,
              ...)
     {
-        query[overlapsAny(query, subject,
-                          maxgap=maxgap, minoverlap=minoverlap,
-                          type=match.arg(type),
-                          ...)]
+        o <- overlapsAny(query, subject,
+                         maxgap=maxgap, minoverlap=minoverlap,
+                         type=match.arg(type),
+                         ...)
+        if (invert) query[!o] else query[o]
     }
 )
 
 setMethod("subsetByOverlaps", c("RangedData", "RangedData"),
           function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"))
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
           {
-              query[unlist(!is.na(findOverlaps(ranges(query), ranges(subject),
-                                               maxgap = maxgap,
-                                               minoverlap = minoverlap,
-                                               type = match.arg(type),
-                                               select = "arbitrary")),
-                           use.names=FALSE),]
+              o <- unlist(!is.na(findOverlaps(ranges(query), ranges(subject),
+                                              maxgap = maxgap,
+                                              minoverlap = minoverlap,
+                                              type = match.arg(type),
+                                              select = "arbitrary")),
+                          use.names=FALSE)
+              if (invert) query[!o,] else query[o,]
           })
 
 setMethod("subsetByOverlaps", c("RangedData", "RangesList"),
           function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"))
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
           {
-              query[unlist(!is.na(findOverlaps(ranges(query), subject,
-                                               maxgap = maxgap,
-                                               minoverlap = minoverlap,
-                                               type = match.arg(type),
-                                               select = "arbitrary")),
-                           use.names=FALSE),]
+              o <- unlist(!is.na(findOverlaps(ranges(query), subject,
+                                              maxgap = maxgap,
+                                              minoverlap = minoverlap,
+                                              type = match.arg(type),
+                                              select = "arbitrary")),
+                          use.names=FALSE)
+              if (invert) query[!o,] else query[o,]
           })
 
 setMethod("subsetByOverlaps", c("RangesList", "RangedData"),
           function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"))
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
           {
-              query[!is.na(findOverlaps(query, ranges(subject),
-                                        maxgap = maxgap,
-                                        minoverlap = minoverlap,
-                                        type = match.arg(type),
-                                        select = "arbitrary"))]
+              o <- !is.na(findOverlaps(query, ranges(subject),
+                                       maxgap = maxgap,
+                                       minoverlap = minoverlap,
+                                       type = match.arg(type),
+                                       select = "arbitrary"))
+              if (invert) query[!o] else query[o]
           })
 
 
@@ -765,5 +772,8 @@ setMethod("ranges", "HitsList", function(x, query, subject) {
 
 findOverlapPairs <- function(query, subject, ...) {
     hits <- findOverlaps(query, subject, ...)
+    if (missing(subject)) {
+        subject <- query
+    }
     Pairs(query, subject, hits=hits)
 }
