@@ -15,6 +15,13 @@
                                    check=FALSE)
 }
 
+### NOT exported but used in the GenomicRanges package
+global2local_revmap <- function(unlisted_revmap, y, x)
+{
+    offsets <- rep.int(start(PartitioningByEnd(x)) - 1L, lengths(y))
+    unlisted_revmap - offsets
+}
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### range()
@@ -101,7 +108,7 @@ setMethod("range", "RangedData", function(x, ..., na.rm) {
 ###
 
 setGeneric("reduce", signature="x",
-    function(x, ...) standardGeneric("reduce")
+    function(x, drop.empty.ranges=FALSE, ...) standardGeneric("reduce")
 )
 
 ### Always return an IRanges (or NormalIRanges) *instance* whatever Ranges
@@ -135,8 +142,7 @@ setMethod("reduce", "Ranges",
         if (is(x, "NormalIRanges"))
             ans <- as(ans, "NormalIRanges")
         if (with.revmap) {
-            revmap <- IntegerList(C_ans$revmap)
-            mcols(ans) <- DataFrame(revmap=revmap)
+            mcols(ans) <- DataFrame(revmap=IntegerList(C_ans$revmap))
         }
         if (with.inframe.attrib) {
             inframe <- new2("IRanges", start=C_ans$inframe.start,
@@ -202,8 +208,7 @@ setMethod("reduce", "CompressedIRangesList",
                                           width=C_ans$width,
                                           check=FALSE)
         if (with.revmap) {
-            revmap <- IntegerList(C_ans$revmap)
-            mcols(ans_unlistData) <- DataFrame(revmap=revmap)
+            mcols(ans_unlistData) <- DataFrame(revmap=IntegerList(C_ans$revmap))
         }
         ans_partitioning <- PartitioningByEnd(C_ans$partitioning_by_end)
         names(ans_partitioning) <- names(x)
@@ -212,11 +217,11 @@ setMethod("reduce", "CompressedIRangesList",
 )
 
 setMethod("reduce", "RangedData",
-          function(x, by = character(), drop.empty.ranges=FALSE,
+          function(x, drop.empty.ranges=FALSE, by=character(),
                    min.gapwidth=1L, with.inframe.attrib=FALSE)
           {
-            .Deprecated(msg=c("the \"reduce\" method for RangedData object ",
-                              "is deprecated"))
+            .Defunct(msg=c("the \"reduce\" method for RangedData object ",
+                           "is defunct"))
             if (!isTRUEorFALSE(drop.empty.ranges))
                 stop("'drop.empty.ranges' must be TRUE or FALSE")
             if (!isSingleNumber(min.gapwidth))
@@ -381,9 +386,9 @@ setMethod("gaps", "MaskCollection",
 setGeneric("disjoin", function(x, ...) standardGeneric("disjoin"))
 
 ### Always return an IRanges *instance* whatever Ranges derivative the input
-### is, so does NOT act like an endomorphism in general. 
+### is, so does NOT act like an endomorphism in general.
 setMethod("disjoin", "Ranges",
-    function(x)
+    function(x, with.revmap=FALSE)
     {
         ## starts: original starts and end+1 when inside another interval
         ## ends: original ends and start-1 when inside another interval
@@ -395,19 +400,25 @@ setMethod("disjoin", "Ranges",
         adj <- new2("IRanges", start=adj_start,
                                width=adj_width,
                                check=FALSE)
-        subsetByOverlaps(adj,  x)
+        adj <- subsetByOverlaps(adj, x)
+        if (with.revmap)
+             mcols(adj)$revmap <- as(sort(findOverlaps(adj, x)),"List")
+        adj
     }
 )
 
 ### Basically a no-op but returns a NormalIRanges *instance* for consistency
-### with how the other inter-range transformations (ranges(), reduce(), gaps())
+### with how the other inter-range transformations (range(), reduce(), gaps())
 ### behave on a NormalIRanges object.
 setMethod("disjoin", "NormalIRanges", function(x) as(x, "NormalIRanges"))
 
-setMethod("disjoin", "RangesList", function(x) endoapply(x, disjoin))
+setMethod("disjoin", "RangesList",
+    function(x, with.revmap=FALSE)
+        endoapply(x, disjoin, with.revmap=with.revmap)
+)
 
 setMethod("disjoin", "CompressedIRangesList",
-          function(x, ...)
+          function(x, with.revmap=FALSE, ...)
           {
               .wunlist <- function(x)
                   ## unlist CompressedIntegerList, with integer(0) as 0
@@ -416,10 +427,10 @@ setMethod("disjoin", "CompressedIRangesList",
                   w[elementNROWS(x) != 0L] <- unlist(x, use.names=FALSE)
                   w
               }
-
+       
               rng <- range(x)
               if (sum(.wunlist(width(rng) + 1)) > .Machine$integer.max)
-                  return(endoapply(x, disjoin,  ...))
+                  return(endoapply(x, disjoin, with.revmap=with.revmap, ...))
 
               ## localize coordinates
               off0 <- head(.wunlist(width(rng) + 1L), -1L)
@@ -427,19 +438,26 @@ setMethod("disjoin", "CompressedIRangesList",
               local <- unlist(shift(x, offset), use.names=FALSE)
 
               ## disjoin
-              lvls <- names(x)
-              if (is.null(lvls))
-                  lvls <- seq_along(x)
-              d <- disjoin(local, ...)
+              d <- disjoin(local, with.revmap=with.revmap, ...)
               vec <- unlist(start(shift(rng, offset)), use.names=FALSE)
+              lvls <- factor(seq_along(x))
               lvls0 <- lvls[elementNROWS(rng) != 0]
               f <- lvls0[findInterval(start(d), vec)]
-              d <- split(d, factor(f, levels=lvls))
-              if (is.null(names(x)))
-                  names(d) <- NULL
+              ans <- split(d, f)
 
               ## globalize coordinates
-              shift(d, -offset)
+              ans <- shift(ans, -offset)
+
+              ## localize 'revmap'
+              if (with.revmap) {
+                  unlisted_ans <- unlist(ans, use.names=FALSE)
+                  mcols(unlisted_ans)$revmap <-
+                      global2local_revmap(mcols(unlisted_ans)$revmap, ans, x)
+                  ans <- relist(unlisted_ans, ans)
+              }
+
+              names(ans) <- names(x)
+              ans
           })
 
 
@@ -467,7 +485,7 @@ setMethod("isDisjoint", "Ranges",
 setMethod("isDisjoint", "NormalIRanges", function(x) TRUE)
 
 setMethod("isDisjoint", "RangesList",
-    function(x) unlist(lapply(x, isDisjoint))
+    function(x) vapply(x, isDisjoint, logical(1))
 )
 
 
