@@ -13,18 +13,20 @@ normargAtomicList1 <- function(arg, List, lx, argname = deparse(substitute(arg))
     arg
 }
 
-normargAtomicList2 <- function(arg, List, lx, eln, argname = deparse(substitute(arg)))
+normargAtomicList2 <- function(arg, List, lx, x_eltNROWS,
+                               argname = deparse(substitute(arg)))
 {
     if (!(is.vector(arg) && length(arg) == 1L)) {
         if (is.vector(arg))
-          arg <- as(rep(S4Vectors:::recycleVector(arg, lx), eln),
+          arg <- as(rep(S4Vectors:::recycleVector(arg, lx), x_eltNROWS),
                     class(unlist(List())))
         else {
           if (!is(arg, "AtomicList"))
             stop("'arg' must be a vector or AtomicList object")
-          if (!isTRUE(all.equal(elementLengths(arg), eln,
+          if (!isTRUE(all.equal(elementNROWS(arg), x_eltNROWS,
                                 check.attributes=FALSE)))
-            arg <- mapply(S4Vectors:::recycleVector, arg, List(as.list(eln)))
+            arg <- mapply(S4Vectors:::recycleVector,
+                          arg, List(as.list(x_eltNROWS)))
           arg <- unlist(arg, use.names=FALSE)
         }
     } else if (is.list(arg)){
@@ -83,18 +85,13 @@ setMethod("shift", "CompressedIRangesList",
           function(x, shift=0L, use.names = TRUE)
           {
               lx <- length(x)
-              eln <- elementLengths(x)
-              shift <- normargAtomicList2(shift, IntegerList, lx, eln)
+              x_eltNROWS <- elementNROWS(x)
+              shift <- normargAtomicList2(shift, IntegerList, lx, x_eltNROWS)
               slot(x, "unlistData", check=FALSE) <-
                 shift(x@unlistData, shift = shift, use.names = use.names)
               x
           })
 
-setMethod("shift", "IntervalForest",
-          function(x, shift=0L, use.names = TRUE)
-            as(shift(as(x, "CompressedIRangesList"), 
-                     shift = shift, use.names = use.names), 
-               "IntervalForest"))
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### narrow()
@@ -144,43 +141,16 @@ setMethod("narrow", "CompressedIRangesList",
           function(x, start = NA, end = NA, width = NA, use.names = TRUE)
           {
               lx <- length(x)
-              eln <- elementLengths(x)
-              start <- normargAtomicList2(start, IntegerList, lx, eln)
-              end <- normargAtomicList2(end, IntegerList, lx, eln)
-              width <- normargAtomicList2(width, IntegerList, lx, eln)
+              x_eltNROWS <- elementNROWS(x)
+              start <- normargAtomicList2(start, IntegerList, lx, x_eltNROWS)
+              end <- normargAtomicList2(end, IntegerList, lx, x_eltNROWS)
+              width <- normargAtomicList2(width, IntegerList, lx, x_eltNROWS)
               slot(x, "unlistData", check=FALSE) <-
                 narrow(x@unlistData, start = start, end = end, width = width,
                        use.names = use.names)
               x
           })
 
-setMethod("narrow", "IntervalForest",
-          function(x, start = NA, end = NA, width = NA, use.names = TRUE)
-            as(narrow(as(x, "CompressedIRangesList"), 
-                     start = start, end = end, width = width,
-                       use.names = use.names), 
-               "IntervalForest"))
-
-### FIXME: This is a quick and dirty implementation that is TOTALLY
-### inefficient. It needs to be improved a lot!
-### FIXME: It's also broken because it can return a GappedRanges object with
-### empty elements (not allowed).
-#setMethod("narrow", "GappedRanges",
-#    function(x, start=NA, end=NA, width=NA, use.names=TRUE)
-#    {
-#        solved_SEW <- solveUserSEW(width(x), start=start, end=end, width=width)
-#        start2 <- start(x) + start(solved_SEW) - 1L
-#        end2 <- start2 + width(solved_SEW) - 1L
-
-#        for (i in seq_len(length(x))) {
-#            x@cnirl[[i]] <- restrict(x[[i]], start=start2[i], end=end2[i])
-#        }
-#        if (!S4Vectors:::normargUseNames(use.names))
-#            names(x) <- NULL
-#        x
-#    }
-#)
-
 setMethod("narrow", "MaskCollection",
     function(x, start=NA, end=NA, width=NA, use.names=TRUE)
     {
@@ -272,21 +242,15 @@ setMethod("resize", "CompressedIRangesList",
           function(x, width, fix = "start", use.names = TRUE)
           {
               lx <- length(x)
-              eln <- elementLengths(x)
-              width <- normargAtomicList2(width, IntegerList, lx, eln)
-              fix <- normargAtomicList2(fix, CharacterList, lx, eln)
+              x_eltNROWS <- elementNROWS(x)
+              width <- normargAtomicList2(width, IntegerList, lx, x_eltNROWS)
+              fix <- normargAtomicList2(fix, CharacterList, lx, x_eltNROWS)
               slot(x, "unlistData", check=FALSE) <-
                 resize(x@unlistData, width = width, fix = fix,
                        use.names = use.names)
               x
           })
 
-setMethod("resize", "IntervalForest",
-          function(x, width, fix = "start", use.names = TRUE)
-            as(resize(as(x, "CompressedIRangesList"),
-                      width = width, fix = fix, use.names = use.names),
-               "IntervalForest"))
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### flank()
@@ -348,21 +312,15 @@ setMethod("flank", "CompressedIRangesList",
           function(x, width, start = TRUE, both = FALSE, use.names = TRUE)
           {
               lx <- length(x)
-              eln <- elementLengths(x)
-              width <- normargAtomicList2(width, IntegerList, lx, eln)
-              start <- normargAtomicList2(start, LogicalList, lx, eln)
+              x_eltNROWS <- elementNROWS(x)
+              width <- normargAtomicList2(width, IntegerList, lx, x_eltNROWS)
+              start <- normargAtomicList2(start, LogicalList, lx, x_eltNROWS)
               slot(x, "unlistData", check=FALSE) <-
                 flank(x@unlistData, width = width, start = start, both = both,
                       use.names = use.names)
               x
           })
 
-setMethod("flank", "IntervalForest",
-          function(x, width, start = TRUE, both = FALSE, use.names = TRUE)
-            as(flank(as(x, "CompressedIRangesList"),
-                     width = width, start = start, both = both,
-                      use.names = use.names),
-               "IntervalForest"))
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### promoters() 
@@ -421,11 +379,6 @@ setMethod("promoters", "CompressedIRangesList",
           }
 )
 
-setMethod("promoters", "IntervalForest",
-          function(x, upstream=2000, downstream=200, ...)
-            as(promoters(as(x, "CompressedIRangesList"),
-                         upstream = upstream, downstream = downstream),
-               "IntervalForest"))
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### reflect()
@@ -599,9 +552,10 @@ setMethod("restrict", "CompressedIRangesList",
                   stop("'keep.all.ranges' must be TRUE or FALSE")
               if (keep.all.ranges) {
                   lx <- length(x)
-                  eln <- elementLengths(x)
-                  start <- normargAtomicList2(start, IntegerList, lx, eln)
-                  end <- normargAtomicList2(end, IntegerList, lx, eln)
+                  x_eltNROWS <- elementNROWS(x)
+                  start <- normargAtomicList2(start, IntegerList,
+                                              lx, x_eltNROWS)
+                  end <- normargAtomicList2(end, IntegerList, lx, x_eltNROWS)
                   slot(x, "unlistData", check=FALSE) <-
                     restrict(x@unlistData, start = start, end = end,
                              keep.all.ranges = keep.all.ranges,
@@ -612,22 +566,6 @@ setMethod("restrict", "CompressedIRangesList",
           })
 
 
-setMethod("restrict", "IntervalForest",
-          function(x, start = NA, end = NA, keep.all.ranges = FALSE,
-                   use.names = TRUE)
-          {
-            if (keep.all.ranges)
-              stop("'keep.all.ranges' must be FALSE in ",
-                   "'restrict,IntervalForest'")
-              
-            as(restrict(as(x, "CompressedIRangesList"),
-                        start = start, end = end,
-                        keep.all.ranges = keep.all.ranges,
-                        use.names = use.names),
-               "IntervalForest")
-          })
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### threebands()
 ###
