@@ -1,6 +1,6 @@
 /****************************************************************************
  *                         Fast inter-range methods                         *
- *                           Author: Herve Pages                            *
+ *                            Author: H. Pag\`es                            *
  ****************************************************************************/
 #include "IRanges.h"
 #include "S4Vectors_interface.h"
@@ -9,26 +9,12 @@
 
 #define R_INT_MIN	(1+INT_MIN)
 
-static int debug = 0;
-
-SEXP debug_inter_range_methods()
-{
-#ifdef DEBUG_IRANGES
-	debug = !debug;
-	Rprintf("Debug mode turned %s in file %s\n",
-		debug ? "on" : "off", __FILE__);
-#else
-	Rprintf("Debug mode not available in file %s\n", __FILE__);
-#endif
-	return R_NilValue;
-}
-
 
 /****************************************************************************
  * Low-level helper functions.
  */
 
-static int get_elt_from_CompressedIRangesList_holderlens_max(
+static int get_maxNROWS_from_CompressedIRangesList_holder(
 		const CompressedIRangesList_holder *x_holder)
 {
 	int x_len, ir_len_max, i, ir_len;
@@ -36,7 +22,7 @@ static int get_elt_from_CompressedIRangesList_holderlens_max(
 	x_len = _get_length_from_CompressedIRangesList_holder(x_holder);
 	ir_len_max = 0;
 	for (i = 0; i < x_len; i++) {
-		ir_len = _get_eltlens_from_CompressedIRangesList_holder(
+		ir_len = _get_eltNROWS_from_CompressedIRangesList_holder(
 				x_holder, i);
 		if (ir_len > ir_len_max)
 			ir_len_max = ir_len;
@@ -119,7 +105,7 @@ static int reduce_ranges(const int *x_start, const int *x_width, int x_len,
 	if (min_gapwidth < 0)
 		error("IRanges internal error in reduce_ranges(): "
 		      "negative min_gapwidth not supported");
-	get_order_of_int_pairs(x_start, x_width, x_len, 0, order_buf, 0);
+	get_order_of_int_pairs(x_start, x_width, x_len, 0, 0, order_buf, 0);
 	out_len = out_len0 = IntPairAE_get_nelt(out_ranges);
 	for (i = 0; i < x_len; i++) {
 		j = order_buf[i];
@@ -262,7 +248,7 @@ SEXP CompressedIRangesList_reduce(SEXP x, SEXP drop_empty_ranges,
 	} else {
 		revmap = NULL;
 	}
-	in_len_max = get_elt_from_CompressedIRangesList_holderlens_max(&x_holder);
+	in_len_max = get_maxNROWS_from_CompressedIRangesList_holder(&x_holder);
 	order_buf = new_IntAE(in_len_max, 0, 0);
 	in_ranges = new_IntPairAE(0, 0);
 	out_ranges = new_IntPairAE(0, 0);
@@ -328,7 +314,7 @@ static int gaps_ranges(const int *x_start, const int *x_width, int x_len,
 		max_end = restrict_start - 1;
 	else
 		max_end = NA_INTEGER;
-	get_order_of_int_pairs(x_start, x_width, x_len, 0, order_buf, 0);
+	get_order_of_int_pairs(x_start, x_width, x_len, 0, 0, order_buf, 0);
 	out_len = out_len0 = IntPairAE_get_nelt(out_ranges);
 	for (i = 0; i < x_len; i++) {
 		j = order_buf[i];
@@ -416,7 +402,7 @@ SEXP CompressedIRangesList_gaps(SEXP x, SEXP start, SEXP end)
 
 	x_holder = _hold_CompressedIRangesList(x);
 	x_len = _get_length_from_CompressedIRangesList_holder(&x_holder);
-	in_len_max = get_elt_from_CompressedIRangesList_holderlens_max(&x_holder);
+	in_len_max = get_maxNROWS_from_CompressedIRangesList_holder(&x_holder);
 	order_buf = new_IntAE(in_len_max, 0, 0);
 	in_ranges = new_IntPairAE(0, 0);
 	out_ranges = new_IntPairAE(0, 0);
